<?php

namespace Drupal\closeblock\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use StringTranslationTrait;

class CloseBlockSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId () {
    return 'CloseBlockSettingsForm';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames () {
    return ['close_block.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm (array $form, FormStateInterface $form_state) {

    $config = $this->config('close_block.settings');

    $form['close_block'] = [
      '#type' => 'fieldset',
      '#title' => t('Closeblock selectors'),
      '#weight' => 0,
      '#attributes' => ['id' => 'close_block_form'],
    ];

    $form['close_block']['close_block_button_text'] = array(
      '#type' => 'textfield',
      '#title' => t('Button text'),
      '#default_value' => $config->get('close_block_button_text'),
      '#description' => t('Button text for block'),
    );

    $form['close_block']['close_block_type'] = [
      '#type' => 'radios',
      '#title' => t('Block close behavior'),
      '#options' => [
        'fadeOut' => t('Fade Out'),
        'slideUp' => t('Slide Up'),
        'none' => t('None'),
      ],
      '#description' => t('The animation type for hiding block.'),
      '#default_value' => $config->get('close_block_type'),
    ];

    $form['close_block']['close_block_speed'] = [
      '#type' => 'number',
      '#title' => t('Animation speed'),
      '#description' => t('The animation speed in milliseconds.'),
      '#default_value' => $config->get('close_block_speed'),
    ];

    $form['close_block']['resetCookie'] = [
      '#type' => 'submit',
      '#value' => t('Reset Cookie'),
      '#description' => t('Reset cookie to visible block'),
      '#id' => 'closeblock-clear-cookie-button',
    ];

    $form['#attached']['library'][] = 'closeblock/closeblock';

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if($form_state->getValue('close_block_speed') < 0){
      $form_state->setErrorByName('close_block_speed',
        $this->t('Animation speed can not be negative.'));
    } else if($form_state->getValue('close_block_speed') > 5000){
      $form_state->setErrorByName('close_block_speed',
        $this->t('Animation speed can not be more that 5000'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm (array &$form, FormStateInterface $form_state) {
    $factory = \Drupal::configFactory()->getEditable('close_block.settings');
    $factory->set('close_block_type', $form_state->getValue('close_block_type'));
    $factory->set('close_block_speed', $form_state->getValue('close_block_speed'));
    $factory->set('close_block_button_text', $form_state->getValue('close_block_button_text'));
    $factory->save();
  }
}